@@ -18,7 +18,7 @@
 "[.mldr" <- function(mldrObject, rowFilter = T) {
   rowFilter <- substitute(rowFilter)
   rows <- eval(rowFilter, mldrObject$dataset, parent.frame())
-  newDataset <- mldrObject$dataset[rows, c(mldrObject$attributesIndexes, mldrObject$labels$index)]
+  newDataset <- mldrObject$dataset[rows, 1:mldrObject$measures$num.attributes]
 
   mldr_from_dataframe(newDataset, labelIndices = mldrObject$labels$index, name = mldrObject$name)
 }
