@@ -21,8 +21,8 @@
   # Check the two mldr's structure
   if(mldr1 == mldr2)
     mldr_from_dataframe(
-      rbind(subset(mldr1$dataset, select = c(mldr1$attributesIndexes, mldr1$labels$index)),
-            subset(mldr2$dataset, select = c(mldr1$attributesIndexes, mldr1$labels$index))),
+      rbind(subset(mldr1$dataset, select = 1:mldr1$measures$num.attributes),
+            subset(mldr2$dataset, select = 1:mldr1$measures$num.attributes)),
       mldr1$labels$index,
       mldr1$name
     )
